@@ -19,7 +19,7 @@ use Version::Compare;
 use Path::Class;
 use ExtUtils::Installed;
 
-our $VERSION = '0.05_10';
+our $VERSION = '0.05_11';
 
 =head1 NAME
 
@@ -76,6 +76,9 @@ script that update the list in a convenient way. It was much more
 longer to write the module than to search by hand so I wish it could
 be useful for you now.
 
+This module is made to search dependencies for I<installed
+distributions>, it is not supposed to manage anything else.
+
 =cut
 
 =head1 WHY ISN'T IT JUST ANOTHER MODULE::SCANDEPS ?
@@ -258,7 +261,7 @@ sub clean_everything {
 			'
 			(.*?)
 			'
-		}{ $1 }xi;
+		}{$1}xi; # Don't insert spaces here
 
 	# Remove the ';' at the end of the line
 	$module =~ s/ ; //xi;
@@ -506,9 +509,7 @@ These patterns should be C<^use> or C<^require>.
 
 Then, Ack will be used to retrieve modules names into lines containing
 patterns and return them into an array (containing also some dirt).
-See
-L<https://metacpan.org/pod/release/SMONF/Dependencies-Searcher-0.05_09/lib/Dependencies/Searcher/AckRequester.pm|Dependencies::Searcher::AckRequester>
-for more informations.
+See L<Dependencies::Searcher::AckRequester> for more informations.
 
 =cut
 
@@ -609,21 +610,17 @@ L<Log::Minimal|Log::Minimal> documentation.
 
 =head1 CAVEATS
 
-=head2 No Win32 / Cygwin support
+=head2 Low Win32 / Cygwin support
 
-This module do not run under Win32 / Cygwin environments because it
-still use non portable code with slashes. It also us-e Ack as a hack
-through a system command even if it was not supposed to be used like
-that.
+This module wans'nt supposed to run under Win32 / Cygwin environments
+because it was using non portable code with slashes. I hope this gets
+better but it still need some testing.
 
-=cut
+It also us-e Ack as a hack through a system command even if it was not
+supposed to be used like that.
 
-=head2 Documentations sections trap
-
-Documentation sections starting by C</^use/> or C</^require/> are not ignored
-as documentation should be but will be considered as code. It will product some
-strange behaviors. That's why sometimes we write "us-e" in this
-documentation. It should be fixed.
+Thanks to cpantesters.org community reports, things should go better and
+better.
 
 =cut
 
@@ -638,7 +635,7 @@ progress on your bug as I make changes.
 
 =head1 TODOs
 
-Most of the time, todos and features are on Github and Questub. 
+Most of the time, todos and features are on Github and Questub.
 See https://github.com/smonff/dependencies-searcher/issues
 
 =head1 SUPPORT
@@ -711,6 +708,8 @@ job.
 
 See L<http://beyondgrep.com/>
 
+=back
+
 See also :
 
 =over 2
@@ -721,8 +720,6 @@ See also :
 
 =back
 
-=back
-
 =head1 LICENSE AND COPYRIGHT
 
 Copyright 2013 smonff.
